@@ -18,7 +18,6 @@
 #include <KIO/ApplicationLauncherJob>
 #include <QApplication>
 #include <QDesktopServices>
-#include <QDesktopWidget>
 #include <QJsonArray>
 #include <QLayout>
 #include <QProcess>
@@ -38,9 +37,7 @@
 bool KontactKCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
     Q_Q(KontactKCMultiDialog);
-    if (!currentProxy
-        || !currentProxy->isChanged()) {
-
+    if (!currentProxy || !currentProxy->isChanged()) {
         return true;
     }
 
